@@ -8,7 +8,6 @@ from patchwork.common.client.scm import (
     ScmPlatformClientProtocol,
     get_slug_from_remote_url,
 )
-from patchwork.logger import logger
 from patchwork.step import Step
 
 
@@ -16,8 +15,7 @@ class CreateIssue(Step):
     required_keys = {"issue_title", "issue_text", "scm_url"}
 
     def __init__(self, inputs: dict):
-        logger.info(f"Run started {self.__class__.__name__}")
-
+        super().__init__(inputs)
         if not all(key in inputs.keys() for key in self.required_keys):
             raise ValueError(f'Missing required data: "{self.required_keys}"')
 
