@@ -1,7 +1,8 @@
 from __future__ import annotations
 
-from patchwork.logger import logger
-from patchwork.step import Step
+from pathlib import Path
+
+from patchwork.step import Step, StepStatus
 
 
 def save_file_contents(file_path, content):
@@ -31,15 +32,23 @@ def handle_indent(src: list[str], target: list[str], start: int, end: int) -> li
     return [indent + line for line in target]
 
 
-def replace_code_in_file(file_path, start_line, end_line, new_code):
-    """Replaces specified lines in a file with new code."""
-    with open(file_path, "r") as file:
-        text = file.read()
+def replace_code_in_file(
+        file_path: str,
+        start_line: int | None,
+        end_line: int | None,
+        new_code: str,
+) -> None:
+    path = Path(file_path)
+    if path.exists():
+        """Replaces specified lines in a file with new code."""
+        text = path.read_text()
 
-    lines = text.splitlines(keepends=True)
+        lines = text.splitlines(keepends=True)
 
-    # Insert the new code at the start line after converting it into a list of lines
-    lines[start_line:end_line] = handle_indent(lines, new_code.splitlines(keepends=True), start_line, end_line)
+        # Insert the new code at the start line after converting it into a list of lines
+        lines[start_line:end_line] = handle_indent(lines, new_code.splitlines(keepends=True), start_line, end_line)
+    else:
+        lines = new_code.splitlines(keepends=True)
 
     # Save the modified contents back to the file
     save_file_contents(file_path, "".join(lines))
@@ -51,8 +60,7 @@ class ModifyCode(Step):
     required_keys = {FILES_TO_PATCH, UPDATED_SNIPPETS_KEY}
 
     def __init__(self, inputs: dict):
-        logger.info(f"Run started {self.__class__.__name__}")
-
+        super().__init__(inputs)
         if not all(key in inputs.keys() for key in self.required_keys):
             raise ValueError(f'Missing required data: "{self.required_keys}"')
 
@@ -64,17 +72,20 @@ class ModifyCode(Step):
         sorted_list = sorted(
             zip(self.files_to_patch, self.extracted_responses), key=lambda x: x[0]["startLine"], reverse=True
         )
+        if len(sorted_list) == 0:
+            self.set_status(StepStatus.SKIPPED, "No code snippets to modify.")
+            return dict(modified_code_files=[])
+
         for code_snippet, extracted_response in sorted_list:
-            uri = code_snippet["uri"]
-            start_line = code_snippet["startLine"]
-            end_line = code_snippet["endLine"]
+            uri = code_snippet.get("uri")
+            start_line = code_snippet.get("startLine")
+            end_line = code_snippet.get("endLine")
             new_code = extracted_response.get("patch")
-            if new_code is None or new_code == "":
+            if new_code is None:
                 continue
 
             replace_code_in_file(uri, start_line, end_line, new_code)
             modified_code_file = dict(path=uri, start_line=start_line, end_line=end_line, **extracted_response)
             modified_code_files.append(modified_code_file)
 
-        logger.info(f"Run completed {self.__class__.__name__}")
         return dict(modified_code_files=modified_code_files)
