@@ -10,6 +10,7 @@ class PR(Step):
     required_keys = PRInputs.__required_keys__
 
     def __init__(self, inputs):
+        super().__init__(inputs)
         missing_keys = self.required_keys.difference(set(inputs.keys()))
         if len(missing_keys) > 0:
             raise ValueError(f'Missing required data: "{missing_keys}"')
@@ -29,11 +30,13 @@ class PR(Step):
             )
         ).run()
 
-        return exclude_none_dict(dict(
-            base_branch=commit_changes_output.get("base_branch"),
-            target_branch=commit_changes_output.get("target_branch"),
-            pr_url=create_pr_outputs.get("pr_url"),
-            pr_number=create_pr_outputs.get("pr_number"),
-            pr_title=prepare_pr_output.get("pr_title"),
-            pr_body=prepare_pr_output.get("pr_body"),
-        ))
+        return exclude_none_dict(
+            dict(
+                base_branch=commit_changes_output.get("base_branch"),
+                target_branch=commit_changes_output.get("target_branch"),
+                pr_url=create_pr_outputs.get("pr_url"),
+                pr_number=create_pr_outputs.get("pr_number"),
+                pr_title=prepare_pr_output.get("pr_title"),
+                pr_body=prepare_pr_output.get("pr_body"),
+            )
+        )
