@@ -1,13 +1,18 @@
 from __future__ import annotations
 
 import json
+import random
+import string
 from pathlib import Path
 
+from chevron import render
+import chevron
+
+from patchwork.common.constants import PROMPT_TEMPLATE_FILE_KEY
 from patchwork.logger import logger
 from patchwork.step import Step, StepStatus
 
-PROMPT_TEMPLATE_FILE_KEY = "prompt_template_file"
-
+chevron.render.__globals__['_html_escape'] = lambda string: string
 
 def _find_by_prompt_template_file(prompt_template_file: str | None, prompt_id: str | None) -> list[dict] | None:
     if prompt_template_file is None or prompt_id is None:
@@ -82,9 +87,13 @@ class PreparePrompt(Step):
             for prompt_part in self.prompt_template:
                 prompt_instance = {}
                 for key, value in prompt_part.items():
-                    new_value = value
-                    for replacement_key, replacement_value in dict_value.items():
-                        new_value = new_value.replace("{{" + replacement_key + "}}", str(replacement_value))
+                    new_value = render(
+                        template=value,
+                        data=dict_value,
+                        partials_path=None,
+                        partials_ext="".join(random.choices(string.ascii_uppercase + string.digits, k=32)),
+                        partials_dict=dict(),
+                    )
                     prompt_instance[key] = new_value
                 prompt.append(prompt_instance)
             prompts.append(prompt)
