@@ -3,7 +3,6 @@ from patchwork.common.client.scm import (
     GitlabClient,
     ScmPlatformClientProtocol,
 )
-from patchwork.logger import logger
 from patchwork.step import Step
 
 
@@ -11,8 +10,7 @@ class ReadIssues(Step):
     required_keys = {"issue_url"}
 
     def __init__(self, inputs: dict):
-        logger.info(f"Run started {self.__class__.__name__}")
-
+        super().__init__(inputs)
         if not all(key in inputs.keys() for key in self.required_keys):
             raise ValueError(f'Missing required data: "{self.required_keys}"')
 
@@ -27,7 +25,13 @@ class ReadIssues(Step):
         if "scm_url" in inputs.keys():
             self.scm_client.set_url(inputs["scm_url"])
 
-        self.issue_texts = self.scm_client.find_issue_by_url(inputs["issue_url"])
+        self.issue = self.scm_client.find_issue_by_url(inputs["issue_url"])
+        if not self.issue:
+            raise ValueError(f"Could not find issue with url: {inputs['issue_url']}")
 
     def run(self) -> dict:
-        return dict(issue_text=[self.issue_texts[0]])
+        return dict(
+            issue_title=self.issue.get("title"),
+            issue_body=self.issue.get("body"),
+            issue_comments=self.issue.get("comments"),
+        )
